@@ -49,6 +49,7 @@
 #ifdef _MSWINDOWS_
 #include <direct.h>
 #include <winioctl.h>
+#include <io.h>
 #endif
 
 #ifdef  HAVE_SYS_INOTIFY_H
@@ -62,6 +63,9 @@
 using namespace UCOMMON_NAMESPACE;
 
 const fsys::offset_t fsys::end = (size_t)(-1);
+charfile cstdin(stdin);
+charfile cstdout(stdout);
+charfile cstderr(stderr);
 
 #ifdef  _MSWINDOWS_
 
@@ -71,13 +75,13 @@ struct LOCAL_REPARSE_DATA_BUFFER
     DWORD  ReparseTag;
     WORD   ReparseDataLength;
     WORD   Reserved;
-    
+
     // IO_REPARSE_TAG_MOUNT_POINT specifics follow
     WORD   SubstituteNameOffset;
     WORD   SubstituteNameLength;
     WORD   PrintNameOffset;
     WORD   PrintNameLength;
-    WCHAR  PathBuffer[1];    
+    WCHAR  PathBuffer[1];
 };
 
 int fsys::remapError(void)
@@ -220,6 +224,29 @@ int fsys::access(const char *path, unsigned mode)
     return 0;
 }
 
+bool fsys::istty(fd_t fd)
+{
+    if(fd == INVALID_HANDLE_VALUE)
+        return false;
+    DWORD type = GetFileType(fd);
+    if(type == FILE_TYPE_CHAR)
+        return true;
+    return false;
+}
+
+bool fsys::istty(void)
+{
+    error = 0;
+    if(fd == INVALID_HANDLE_VALUE)
+        return false;
+    DWORD type = GetFileType(fd);
+    if(!type)
+        error = remapError();
+    if(type == FILE_TYPE_CHAR)
+        return true;
+    return false;
+}
+
 void fsys::close(void)
 {
     error = 0;
@@ -541,6 +568,20 @@ ssize_t fsys::write(const void *buf, size_t len)
     return rtn;
 }
 
+bool fsys::istty(fd_t fd)
+{
+    if(isatty(fd))
+        return true;
+    return false;
+}
+
+bool fsys::istty(void)
+{
+    if(isatty(fd))
+        return true;
+    return false;
+}
+
 void fsys::close(void)
 {
     error = 0;
@@ -947,6 +988,58 @@ int fsys::remove(const char *path)
     return 0;
 }
 
+int fsys::copy(const char *oldpath, const char *newpath, size_t size)
+{
+    int result = 0;
+    char *buffer = new char[size];
+    fsys src, dest;
+    ssize_t count = size;
+
+    if(!buffer) {
+        result = ENOMEM;
+        goto end;
+    }
+
+    remove(newpath);
+
+    src.open(oldpath, fsys::ACCESS_STREAM);
+    if(!is(src))
+        goto end;
+
+    dest.create(newpath, fsys::ACCESS_STREAM, 0664);
+    if(!is(dest))
+        goto end;
+
+    while(count > 0) {
+        count = src.read(buffer, size);
+        if(count < 0) {
+            result = src.err();
+            goto end;
+        }
+        if(count > 0)
+            count = dest.write(buffer, size);
+        if(count < 0) {
+            result = dest.err();
+            goto end;
+        }
+    }
+
+end:
+    if(is(src))
+        src.close();
+
+    if(is(dest))
+        dest.close();
+
+    if(buffer)
+        delete[] buffer;
+
+    if(result != 0)
+        remove(newpath);
+
+    return result;
+}
+
 int fsys::rename(const char *oldpath, const char *newpath)
 {
     if(::rename(oldpath, newpath))
@@ -1250,6 +1343,18 @@ charfile::~charfile()
     close();
 }
 
+bool charfile::istty(void)
+{
+#ifdef  _MSWINDOWS_
+    if(_isatty(_fileno(fp)))
+        return true;
+#else
+    if(isatty(fileno(fp)))
+        return true;
+#endif
+    return false;
+}
+
 void charfile::open(const char *path, const char *mode)
 {
     if(fp)
