@@ -1290,12 +1290,6 @@ String shell::path(path_t id)
         return result;
 
     switch(id) {
-    case SYSTEM_CERTIFICATES:
-        result ^= SSL_CERTS;
-        break;
-    case SYSTEM_KEYS:
-        result ^= SSL_PRIVATE;
-        break;
     case PROGRAM_CONFIG:
         result = str("~\\Software\\Applications\\") + _domain;
         break;
@@ -1742,12 +1736,6 @@ String shell::path(path_t id)
         return result;
 
     switch(id) {
-    case SYSTEM_CERTIFICATES:
-        result = path(SYSTEM_PREFIX, SSL_CERTS);
-        break;
-    case SYSTEM_KEYS:
-        result = path(SYSTEM_PREFIX, SSL_PRIVATE);
-        break;
     case USER_DEFAULTS:
         home = ::getenv("HOME");
         if(!home)
@@ -2593,6 +2581,14 @@ void shell::setsym(const char *name, const char *value)
     symlock.release();
 }
 
+String shell::path(String& prefix, const char *dir)
+{
+    if(*dir == '\\' || *dir == '/')
+        return str(dir);
+
+    return prefix + "/" + dir;
+}
+
 String shell::path(path_t id, const char *dir)
 {
     string_t result;
