@@ -278,6 +278,18 @@ public:
      */
     int drop(offset_t size = 0);
 
+    /**
+     * See if current file stream is a tty device.
+     * @return true if device.
+     */
+    bool istty(void);
+
+    /**
+     * See if the file handle is a tty device.
+     * @return true if device.
+     */
+    static bool istty(fd_t fd);
+
     /**
      * Read data from descriptor or scan directory.
      * @param buffer to read into.
@@ -351,6 +363,15 @@ public:
      */
     static int remove(const char *path);
 
+    /**
+     * Copy a file.
+     * @param source file.
+     * @param target file.
+     * @param size of buffer.
+     * @return error number or 0 on success.
+     */
+    static int copy(const char *source, const char *target, size_t size = 1024);
+
     /**
      * Rename a file.
      * @param oldpath to rename from.
@@ -597,6 +618,9 @@ public:
     static inline bool isdev(struct stat *inode)
         {return S_ISBLK(inode->st_mode) || S_ISCHR(inode->st_mode);}
 
+    static inline bool ischar(struct stat *inode)
+        {return S_ISCHR(inode->st_mode);}
+
     static inline bool isdisk(struct stat *inode)
         {return S_ISBLK(inode->st_mode);}
 
@@ -620,6 +644,8 @@ private:
     int _getch(void);
 
 public:
+    typedef ::fpos_t bookmark_t;
+
     /**
      * Construct a charfile from an existing FILE pointer.
      * @param file to use.
@@ -704,10 +730,10 @@ public:
     size_t get(void *data, size_t size)
         { return fp == NULL ? 0 : fread(data, 1, size, fp);}
 
-    inline void get(fpos_t& pos)
+    inline void get(bookmark_t& pos)
         { if(fp) fsetpos(fp, &pos);}
 
-    inline void set(fpos_t& pos)
+    inline void set(bookmark_t& pos)
         { if(fp) fgetpos(fp, &pos);}
 
     int err(void);
@@ -727,6 +753,8 @@ public:
         {if(fp) ::rewind(fp);}
 
     size_t printf(const char *format, ...) __PRINTF(2, 3);
+
+    bool istty(void);
 };
 
 String str(charfile& fp, strsize_t size);
@@ -736,6 +764,8 @@ String str(charfile& fp, strsize_t size);
  */
 typedef fsys fsys_t;
 
+extern charfile cstdin, cstdout, cstderr;
+
 END_NAMESPACE
 
 #endif
