@@ -113,8 +113,8 @@ public:
      * Path types to retrieve.
      */
     typedef enum {
-        PROGRAM_CONFIG, SERVICE_CONFIG, USER_DEFAULTS, SYSTEM_CERTIFICATES,
-        SYSTEM_KEYS, USER_HOME, SERVICE_DATA, SYSTEM_TEMP, USER_CACHE,
+        PROGRAM_CONFIG, SERVICE_CONFIG, USER_DEFAULTS,
+        USER_HOME = USER_DEFAULTS + 3, SERVICE_DATA, SYSTEM_TEMP, USER_CACHE,
         SERVICE_CACHE, USER_DATA, USER_CONFIG, SYSTEM_CFG, SYSTEM_ETC,
         SYSTEM_VAR, SYSTEM_PREFIX, SYSTEM_SHARE, PROGRAM_PLUGINS,
         PROGRAM_TEMP} path_t;
@@ -631,10 +631,18 @@ public:
     /**
      * Get a merged path.  If the path requested is a full path, then
      * the prefix is ignored.
+     * @param id of prefix.
      * @param directory path to merge with prefix.
      */
     static String path(path_t id, const char *directory);
 
+    /**
+     * Join a prefix with a path.
+     * @param prefix to merge with.
+     * @param directory or file path to merge.
+     */
+    static String path(String& prefix, const char *directory);
+
     /**
      * Bind application to text domain for internationalization.  This
      * is useful if the argv0 argument can vary because of a symlinked
